==> slang_retail_assistant-4.0.6.tar.gz: lib/src/assistant_ui_position.dart <==
part of slang_retail_assistant;

class AssistantUIPosition {

  BaseUIPosition baseUIPosition;
  int offsetX;
  int offsetY;
  bool isDraggable;
  bool isForced;

  HashMap<String,Object> _covertToHashmap() {
    var assistantUIPositionMap = HashMap<String,Object>();
    assistantUIPositionMap["baseUIPosition"] = baseUIPosition.stringValue;
    assistantUIPositionMap["offsetX"] = offsetX;
    assistantUIPositionMap["offsetY"] = offsetY;
    assistantUIPositionMap["draggable"] = isDraggable;
    assistantUIPositionMap["forcedAtStartup"] = isForced;
    return assistantUIPositionMap;
  }
}

enum BaseUIPosition {
  BOTTOM_CENTER,
  BOTTOM_LEFT,
  BOTTOM_RIGHT,
  CENTER_LEFT,
  CENTER,
  CENTER_RIGHT,
  TOP_LEFT,
  TOP_CENTER,
  TOP_RIGHT
}

extension BaseUIPositionExtension on BaseUIPosition {
  String get stringValue {
    switch (this) {
      case BaseUIPosition.BOTTOM_CENTER:
        return 'BOTTOM_CENTER';
      case BaseUIPosition.BOTTOM_LEFT:
        return 'BOTTOM_LEFT';
      case BaseUIPosition.BOTTOM_RIGHT:
        return 'BOTTOM_RIGHT';
      case BaseUIPosition.CENTER_LEFT:
        return 'CENTER_LEFT';
      case BaseUIPosition.CENTER:
        return 'CENTER';
      case BaseUIPosition.CENTER_RIGHT:
        return 'CENTER_RIGHT';
      case BaseUIPosition.TOP_LEFT:
        return 'TOP_LEFT';
      case BaseUIPosition.TOP_CENTER:
        return 'TOP_CENTER';
      case BaseUIPosition.TOP_RIGHT:
        return 'TOP_RIGHT';
      default:
        return null;
    }
  }
}

==> slang_retail_assistant-4.0.8.tar.gz: lib/src/assistant_ui_position.dart <==
part of slang_retail_assistant;

class AssistantUIPosition {

  BaseUIPosition baseUIPosition;
  int offsetX;
  int offsetY;
  bool isDraggable;
  bool isForced;

  HashMap<String,Object> _covertToHashmap() {
    var assistantUIPositionMap = HashMap<String,Object>();
    assistantUIPositionMap["baseUIPosition"] = (baseUIPosition ?? BaseUIPosition.BOTTOM_CENTER).stringValue;
    assistantUIPositionMap["offsetX"] = offsetX;
    assistantUIPositionMap["offsetY"] = offsetY;
    assistantUIPositionMap["draggable"] = isDraggable;
    assistantUIPositionMap["forcedAtStartup"] = isForced;
    return assistantUIPositionMap;
  }
}

enum BaseUIPosition {
  BOTTOM_CENTER,
  BOTTOM_LEFT,
  BOTTOM_RIGHT,
  CENTER_LEFT,
  CENTER,
  CENTER_RIGHT,
  TOP_LEFT,
  TOP_CENTER,
  TOP_RIGHT
}

extension BaseUIPositionExtension on BaseUIPosition {
  String get stringValue {
    switch (this) {
      case BaseUIPosition.BOTTOM_CENTER:
        return 'BOTTOM_CENTER';
      case BaseUIPosition.BOTTOM_LEFT:
        return 'BOTTOM_LEFT';
      case BaseUIPosition.BOTTOM_RIGHT:
        return 'BOTTOM_RIGHT';
      case BaseUIPosition.CENTER_LEFT:
        return 'CENTER_LEFT';
      case BaseUIPosition.CENTER:
        return 'CENTER';
      case BaseUIPosition.CENTER_RIGHT:
        return 'CENTER_RIGHT';
      case BaseUIPosition.TOP_LEFT:
        return 'TOP_LEFT';
      case BaseUIPosition.TOP_CENTER:
        return 'TOP_CENTER';
      case BaseUIPosition.TOP_RIGHT:
        return 'TOP_RIGHT';
      default:
        return null;
    }
  }
}
